@@ -7,3 +7,5 @@ from juno import digital_account
 from juno import notification
 from juno import payment
 from juno import transfer
+from juno import additional_data
+from juno import onboarding
